@@ -37,6 +37,13 @@ extern "C" {
 #endif /* __cplusplus */
 
 
+/**
+ * Get libsvn_fs version information.
+ * @since New in 1.1.
+ */
+const svn_version_t *svn_fs_version (void);
+
+
 /* Opening and creating filesystems.  */
 
 
@@ -48,24 +55,12 @@ typedef struct svn_fs_t svn_fs_t;
 #define SVN_FS_CONFIG_BDB_TXN_NOSYNC            "bdb-txn-nosync"
 #define SVN_FS_CONFIG_BDB_LOG_AUTOREMOVE        "bdb-log-autoremove"
 
-
-/** Create a new filesystem object in @a pool.
- *
- * It doesn't refer to any actual repository yet; you need to invoke
- * @c svn_fs_open_* or @c svn_fs_create_* on it for that to happen. If
- * @a fs_config is not @c NULL, the options it contains modify the
- * behaviour of the filesystem. The interpretation of @a fs_config is
- * specific to the filesystem back-end.
- *
- * @note The lifetime of @a fs_config must not be shorter than @a
- * pool's. It's a good idea to allocate @a fs_config from @a pool or
- * one of its ancestors.
- *
- * @note You probably don't want to use this directly, especially not
- * if it's followed immediately by a call to @c svn_fs_open_berkeley().
- * Take a look at @c svn_repos_open() instead.
- */
-svn_fs_t *svn_fs_new (apr_hash_t *fs_config, apr_pool_t *pool);
+/* @since New in 1.1. */
+#define SVN_FS_CONFIG_FS_TYPE                   "fs-type"
+/* @since New in 1.1. */
+#define SVN_FS_TYPE_BDB                         "bdb"
+/* @since New in 1.1. */
+#define SVN_FS_TYPE_FSFS                        "fsfs"
 
 
 /** The type of a warning callback function.  @a baton is the value specified
@@ -93,59 +88,95 @@ void svn_fs_set_warning_func (svn_fs_t *fs,
 
 
 
+
+/**
+ * @since New in 1.1.
+ *
+ * Create a new, empty Subversion filesystem, stored in the directory
+ * @a path, and return a pointer to it in @a *fs_p.  @a path must not
+ * currently exist, but its parent must exist.  If @a fs_config is not
+ * @c NULL, the options it contains modify the behavior of the
+ * filesystem.  The interpretation of @a fs_config is specific to the
+ * filesystem back-end.  The new filesystem may be closed by
+ * destroying @a pool.
+ *
+ * @note The lifetime of @a fs_config must not be shorter than @a
+ * pool's. It's a good idea to allocate @a fs_config from @a pool or
+ * one of its ancestors.
+ *
+ * If @a fs_config contains a value for @c SVN_FS_CONFIG_FS_TYPE, that
+ * value determines the filesystem type for the new filesystem.
+ * Currently defined values are:
+ *
+ *   SVN_FS_TYPE_BDB   Berkeley-DB implementation
+ *   SVN_FS_TYPE_FSFS  Native-filesystem implementation
+ *
+ * Otherwise, the BDB filesystem type is assumed.  Once the filesystem
+ * is created, its type will be recorded so that other functions will
+ * know how to operate on it.
+ */
+svn_error_t *svn_fs_create (svn_fs_t **fs_p, const char *path,
+                            apr_hash_t *fs_config, apr_pool_t *pool);
+
+/** 
+ * @since New in 1.1.
+ *
+ * Open a Subversion filesystem located in the directory @a path, and
+ * return a pointer to it in @a *fs_p.  If @a fs_config is not @c
+ * NULL, the options it contains modify the behavior of the
+ * filesystem.  The interpretation of @a fs_config is specific to the
+ * filesystem back-end.  The opened filesystem may be closed by
+ * destroying @a pool.
+ *
+ * @note The lifetime of @a fs_config must not be shorter than @a
+ * pool's. It's a good idea to allocate @a fs_config from @a pool or
+ * one of its ancestors.
+ *
+ * Only one thread may operate on any given filesystem object at once.
+ * Two threads may access the same filesystem simultaneously only if
+ * they open separate filesystem objects.
+ *
+ * NOTE: you probably don't want to use this directly.  Take a look at
+ * @c svn_repos_open() instead.
+ */
+svn_error_t *svn_fs_open (svn_fs_t **fs_p, const char *path,
+                          apr_hash_t *config, apr_pool_t *pool);
+
+/** 
+ * @since New in 1.1.
+ *
+ * Return the path to @a fs's repository, allocated in @a pool.
+ * Note: this is just what was passed to @c svn_fs_create() or
+ * @a svn_fs_open() -- might be absolute, might not.
+ */
+const char *svn_fs_path (svn_fs_t *fs, apr_pool_t *pool);
+
+/**
+ * @since New in 1.1.
+ *
+ * Delete the filesystem at @a path. */
+svn_error_t *svn_fs_delete_fs (const char *path, apr_pool_t *pool);
+
+/** 
+ * @since New in 1.1.
+ *
+ * Copy a possibly live Subversion filesystem from @a src_path to
+ * @a dest_path.  If @a clean is @c TRUE, perform cleanup on the
+ * source filesystem as part of the copy operation; currently, this
+ * means deleting copied, unused logfiles for a Berkeley DB source
+ * filesystem.
+ */
+svn_error_t *svn_fs_hotcopy (const char *src_path, const char *dest_path,
+                             svn_boolean_t clean, apr_pool_t *pool);
+
 /** Subversion filesystems based on Berkeley DB.
- * 
- * There are many possible ways to implement the Subversion filesystem
- * interface.  You could implement it directly using ordinary POSIX
- * filesystem operations; you could build it using an SQL server as a
- * back end; you could build it on RCS; and so on.
  *
- * The functions on this page create filesystem objects that use
- * Berkeley DB (http://www.sleepycat.com) to store their data.
- * Berkeley DB supports transactions and recoverability, making it
- * well-suited for Subversion.
- *
- * A Berkeley DB ``environment'' is a Unix directory containing
- * database files, log files, backing files for shared memory buffers,
- * and so on --- everything necessary for a complex database
- * application.  Each Subversion filesystem lives in a single Berkeley
- * DB environment.
+ * The following functions are specific to Berkeley DB filesystems.
  *
  * @defgroup svn_fs_bdb berkeley db filesystems
  * @{
  */
 
-/** Create a new, empty Subversion filesystem, stored in a Berkeley DB
- * environment under @a path, a utf8-encoded path.  Make @a fs refer to 
- * this new filesystem.  @a fs provides the memory pool, warning function,
- * etc.  If @a path exists, it must be an empty directory.
- */
-svn_error_t *svn_fs_create_berkeley (svn_fs_t *fs, const char *path);
-
-
-/** Make @a fs refer to the Berkeley DB-based Subversion filesystem at
- * @a path.  @a path is utf8-encoded, and must refer to a file or directory
- * created by @c svn_fs_create_berkeley.
- *
- * Only one thread may operate on any given filesystem object at once.
- * Two threads may access the same filesystem simultaneously only if
- * they open separate filesystem objects.  
- *
- * NOTE: you probably don't want to use this directly, especially not
- * if it's immediately preceded by a call to @c svn_fs_new().  Take a
- * look at @c svn_repos_open() instead.
- */
-svn_error_t *svn_fs_open_berkeley (svn_fs_t *fs, const char *path);
-
-
-/** Return the utf8-encoded path to @a fs's repository, allocated in
- * @a pool.  Note: this is just what was passed to
- * @c svn_fs_create_berkeley() or @a svn_fs_open_berkeley() -- might be
- * absolute, might not.
- */
-const char *svn_fs_berkeley_path (svn_fs_t *fs, apr_pool_t *pool);
-
-
 /** Register an error handling function for Berkeley DB error messages.
  * If a Berkeley DB error occurs, the filesystem will call @a handler
  * with two strings: an error message prefix, which will be zero, and
@@ -164,23 +195,6 @@ svn_error_t *svn_fs_set_berkeley_errcall (svn_fs_t *fs,
                                           void (*handler) (const char *errpfx,
                                                            char *msg));
 
-/** Delete the Berkeley DB-based filesystem @a path.  This deletes the
- * database files, log files, shared memory segments, etc.  @a path should
- * refer to a file or directory created by @c svn_fs_create_berkeley.
- */
-svn_error_t *svn_fs_delete_berkeley (const char *path, apr_pool_t *pool);
-
-
-/** Hot copy Subversion filesystem, stored in a Berkeley DB environment under 
- * @a src_path to @a dest_path. If @a clean_logs is used is @c TRUE, 
- * delete copied, unused log files from source repository at @a src_path
- * Using @a pool for any necessary memory allocations.
- */
-svn_error_t *svn_fs_hotcopy_berkeley (const char *src_path, 
-                                      const char *dest_path, 
-                                      svn_boolean_t clean_logs,
-                                      apr_pool_t *pool);
-
 /** Perform any necessary non-catastrophic recovery on a Berkeley
  * DB-based Subversion filesystem, stored in the environment @a path.
  * Do any necessary allocation within @a pool.
@@ -225,6 +239,36 @@ svn_error_t *svn_fs_berkeley_logfiles (apr_array_header_t **logfiles,
                                        apr_pool_t *pool);
 
 
+/**
+ * The following functions are similar to their generic counterparts,
+ * but only work on Berkeley DB filesystems.
+ *
+ * @defgroup svn_fs_bdb_deprecated berkeley db filesystem compatibility
+ * @{
+ */
+
+/** @deprecated Provided for backward compatibility with the 1.0.0 API. */
+svn_fs_t *svn_fs_new (apr_hash_t *fs_config, apr_pool_t *pool);
+
+/** @deprecated Provided for backward compatibility with the 1.0.0 API. */
+svn_error_t *svn_fs_create_berkeley (svn_fs_t *fs, const char *path);
+
+/** @deprecated Provided for backward compatibility with the 1.0.0 API. */
+svn_error_t *svn_fs_open_berkeley (svn_fs_t *fs, const char *path);
+
+/** @deprecated Provided for backward compatibility with the 1.0.0 API. */
+const char *svn_fs_berkeley_path (svn_fs_t *fs, apr_pool_t *pool);
+
+/** @deprecated Provided for backward compatibility with the 1.0.0 API. */
+svn_error_t *svn_fs_delete_berkeley (const char *path, apr_pool_t *pool);
+
+/** @deprecated Provided for backward compatibility with the 1.0.0 API. */
+svn_error_t *svn_fs_hotcopy_berkeley (const char *src_path, 
+                                      const char *dest_path, 
+                                      svn_boolean_t clean_logs,
+                                      apr_pool_t *pool);
+/** @} */
+
 /** @} */
 
 
@@ -270,19 +314,16 @@ int svn_fs_compare_ids (const svn_fs_id_t *a, const svn_fs_id_t *b);
 
 /** Return non-zero IFF the nodes associated with @a id1 and @a id2 are
  * related, else return zero.  
- *
- * NOTE: While this might seem redundant in the presence of
- * @c svn_fs_compare_ids (looking for a return value != -1), it is
- * slightly faster to run if the equality case is not interesting to
- * you.
  */
 svn_boolean_t svn_fs_check_related (const svn_fs_id_t *id1,
                                     const svn_fs_id_t *id2);
 
 
-/** Parse the @a len bytes at @a data as a node revision @a id.  Return zero 
- * if the bytes are not a properly-formed @a id.  Allocate the parsed @a id 
- * in @a pool.
+/** @deprecated Provided for backward compatibility with the 1.0.0 API.
+ *
+ * NOTE: This function is not guaranteed to work with all filesystem
+ * types.  There is currently no un-deprecated equivalent; contact the
+ * Subversion developers if you have a need for it.
  */
 svn_fs_id_t *svn_fs_parse_id (const char *data, 
                               apr_size_t len,
@@ -786,7 +827,7 @@ svn_error_t *svn_fs_node_created_rev (svn_revnum_t *revision,
                                       const char *path,
                                       apr_pool_t *pool);
 
-/** Set @a *created_path to the path at with @a path under @root was
+/** Set @a *created_path to the path at which @a path under @a root was
  * created.  Use @a pool for all allocations.  Callers may use this
  * function in conjunction with svn_fs_node_created_rev() perform a
  * reverse lookup of the mapping of (path, revision) -> node-id that
@@ -958,7 +999,7 @@ typedef struct svn_fs_dirent_t
 } svn_fs_dirent_t;
 
 
-/** Set @a *table_p to a newly allocated APR hash table containing the
+/** Set @a *entries_p to a newly allocated APR hash table containing the
  * entries of the directory at @a path in @a root.  The keys of the table
  * are entry names, as byte strings, excluding the final null
  * character; the table's values are pointers to @c svn_fs_dirent_t
